==> maDB_1.4.0.tar.gz: maDB/man/getMDB.Rd <==
\name{getMDB}
\alias{getMDB}
\title{Retrieving regulation values from a database.}
\description{
  \code{getMDB} this function reads the regulation (M) values from the selected comparisons out of a PostgreSQL database. Micro array experiments can be stored into a PostgreSQL database using the \code{publishToDB} method of the \code{EexprSet} object. The corresponding regulation values can then be calculated with the \code{calculateDBRegulations} function.
}
\usage{
getMDB(con,ids=NULL,comparisons.pk=NULL,v=TRUE,column.names="description")
}
\arguments{
  \item{con}{A connection object (create it with the dbConnect.PgSQL.conn function from the package RdbiPgSQL)}
  \item{ids}{The IDs of the genes from which the expression values should be retrieved. In the case of Affymetrix GeneChips the Affymetrix IDs should be used (as they are used as rownames in the \code{exprs} matrix in the \code{exprSet} objects).}
  \item{comparisons.pk}{the primary keys of the comparisons in the database from which the regulation values should be retrieved. To get all available comparisons from the database call \code{dbGetResult(dbSendQuery(con,"SELECT * FROM comparisons"))}, where \code{con} is the database connection object and the column \code{comparisons\_pk} contains the primary keys. This SQL call can be extended to the samples that are hybridized in the signal channel used as \dQuote{red} signal channel (\code{M = log2( R / G)}): \code{dbGetResult(dbSendQuery(con,"SELECT * FROM comparisons JOIN signal\_channels ON (red\_signal\_channel=signal\_channels\_pk) JOIN samples ON (samples\_fk=samples\_pk)"))}. By switching the \dQuote{red\_signal\_channel} with \dQuote{green\_signal\_channel} the call retrieves the same information, but with information about the green signal channel (usually the control sample).}
  \item{column.names}{The information that should be used as column names of the returned regulation values matrix. Allowed are all column names of the sample and comparisons database tables.}
  \item{v}{If TRUE additional information will be printed to the console.}
}
\details{
This function is useful, if one wants to get regulation values of a set of genes in a set of comparisons.
}
\references{}
\author{Johannes Rainer}

\seealso{
    \code{\link{publishToDB}}
    \code{\link{dbGetExperimentInfo}}
    \code{\link{dbConnect}}
    \code{\link{loadFromDB}}
    \code{\link{getEDB}}
}

\keyword{data}

==> maDB_1.6.0.tar.gz: maDB/man/getMDB.Rd <==
\name{getMDB}
\alias{getMDB}
\title{Retrieving regulation values from a database.}
\description{
  \code{getMDB} this function reads the regulation (M) values from the selected comparisons out of a PostgreSQL database. Micro array experiments can be stored into a PostgreSQL database using the \code{publishToDB} method of the \code{EexprSet} object. The corresponding regulation values can then be calculated with the \code{calculateDBRegulations} function.
}
\usage{
getMDB(con,ids=NULL,comparisons.pk=NULL,v=TRUE,column.names="description")
}
\arguments{
  \item{con}{A connection object (create it with the dbConnect.PgSQL.conn function from the package RdbiPgSQL)}
  \item{ids}{The IDs of the genes from which the expression values should be retrieved. In the case of Affymetrix GeneChips the Affymetrix IDs should be used (as they are used as rownames in the \code{exprs} matrix in the \code{exprSet} objects).}
  \item{comparisons.pk}{the primary keys of the comparisons in the database from which the regulation values should be retrieved. To get all available comparisons from the database call \code{dbGetResult(dbSendQuery(con,"SELECT * FROM comparisons"))}, where \code{con} is the database connection object and the column \code{comparisons\_pk} contains the primary keys. This SQL call can be extended to the samples that are hybridized in the signal channel used as \dQuote{red} signal channel (\code{M = log2( R / G)}): \code{dbGetResult(dbSendQuery(con,"SELECT * FROM comparisons JOIN signal\_channels ON (red\_signal\_channel=signal\_channels\_pk) JOIN samples ON (samples\_fk=samples\_pk)"))}. By switching the \dQuote{red\_signal\_channel} with \dQuote{green\_signal\_channel} the call retrieves the same information, but with information about the green signal channel (usually the control sample).}
  \item{column.names}{The information that should be used as column names of the returned regulation values matrix. Allowed are all column names of the sample and comparisons database tables.}
  \item{v}{If TRUE additional information will be printed to the console.}
}
\details{
This function is useful, if one wants to get regulation values of a set of genes in a set of comparisons.
}
\references{}
\author{Johannes Rainer}

\seealso{
    \code{\link{publishToDB}}
    \code{\link{dbGetExperimentInfo}}
%    \code{\link{dbConnect}}
    \code{\link{loadFromDB}}
    \code{\link{getEDB}}
}

\keyword{data}
